@@ -14,7 +14,7 @@ pub extern crate derivation_path;
 pub extern crate ed25519_dalek;
 
 pub use derivation_path::{ChildIndex, DerivationPath};
-pub use ed25519_dalek::{PublicKey, SecretKey};
+pub use ed25519_dalek::{Keypair as DalekKeypair, PublicKey, SecretKey};
 
 use hmac::{Hmac, Mac, NewMac};
 use sha2::Sha512;
@@ -151,18 +151,29 @@ impl ExtendedSecretKey {
         })
     }
 
-    /// Get the associated public key
     #[inline]
     pub fn public_key(&self) -> PublicKey {
         PublicKey::from(&self.secret_key)
     }
 
+    #[inline]
+    pub fn keypair(&self) -> DalekKeypair {
+        let secret = self.secret_key();
+        let public = self.public_key();
+        DalekKeypair { secret, public }
+    }
+
+    #[inline]
+    fn secret_key(&self) -> SecretKey {
+        SecretKey::from_bytes(self.secret_key.as_bytes()).unwrap()
+    }
+
     #[inline]
     fn clone(&self) -> Self {
         Self {
             depth: self.depth,
             child_index: self.child_index,
-            secret_key: SecretKey::from_bytes(&self.secret_key.to_bytes()).unwrap(),
+            secret_key: self.secret_key(),
             chain_code: self.chain_code,
         }
     }
@@ -186,9 +197,13 @@ mod tests {
     #[test]
     fn bytes_conversion() {
         let xprv = root("000102030405060708090a0b0c0d0e0f");
+        let pair = xprv.keypair();
         let bytes = xprv.to_bytes();
         let xprv2 = ExtendedSecretKey::from_bytes(&bytes).unwrap();
+        let pair2 = xprv2.keypair();
         assert_eq!(xprv, xprv2);
+        assert_eq!(pair.secret.as_bytes(), pair2.secret.as_bytes());
+        assert_eq!(pair.public.as_bytes(), pair2.public.as_bytes());
     }
 
     #[test]
